@@ -10,9 +10,9 @@ class CompileCommand(CommandBase):
         self._base_args.append(commands.COMPILE)
 
     def __call__(self,
-                 sketch, build_cache_path=None, build_path=None, build_properties=None, fqbn=None, output=None,
+                 sketch, build_cache_path=None, build_path=None, build_properties=None, fqbn=None, output_dir=None,
                  port=None, preprocess=None, show_properties=None, upload=None, verify=None, vid_pid=None,
-                 warnings=None, libraries=None, optimize_for_debug=None, dry_run=None):
+                 warnings=None, libraries=None, optimize_for_debug=None, dry_run=None, programmer=None):
         args = []
         if build_cache_path:
             args.extend([flags.BUILD_CACHE_PATH, CommandBase._strip_arg(build_cache_path)])
@@ -22,8 +22,8 @@ class CompileCommand(CommandBase):
             args.extend([flags.BUILD_PROPERTIES, CommandBase._strip_arg(build_properties)])
         if fqbn:
             args.extend([flags.FQBN, CommandBase._strip_arg(fqbn)])
-        if output:
-            args.extend([flags.OUTPUT, CommandBase._strip_arg(output)])
+        if output_dir:
+            args.extend([flags.OUTPUT_DIR, CommandBase._strip_arg(output_dir)])
         if port:
             args.extend([flags.PORT, CommandBase._strip_arg(port)])
         if preprocess is True:
@@ -45,5 +45,7 @@ class CompileCommand(CommandBase):
             args.append(flags.OPTIMIZE_FOR_DEBUG)
         if dry_run is True:
             args.append(flags.DRY_RUN)
+        if programmer:
+            args.extend([flags.PROGRAMMER, CommandBase._strip_arg(programmer)])
         args.append(CommandBase._strip_arg(sketch))
         return self._exec(args)
