@@ -9,16 +9,18 @@ class UploadCommand(CommandBase):
         CommandBase.__init__(self, base_args)
         self._base_args.append(commands.UPLOAD)
 
-    def __call__(self, sketch=None, fqbn=None, input=None, port=None, verify=None):
+    def __call__(self, sketch=None, fqbn=None, input_dir=None, port=None, verify=None, programmer=None):
         args = []
         if fqbn:
             args.extend([flags.FQBN, CommandBase._strip_arg(fqbn)])
-        if input:
-            args.extend([flags.INPUT, CommandBase._strip_arg(input)])
+        if input_dir:
+            args.extend([flags.INPUT_DIR, CommandBase._strip_arg(input_dir)])
         if port:
             args.extend([flags.PORT, CommandBase._strip_arg(port)])
         if verify is True:
             args.append(flags.VERIFY)
         if sketch:
             args.append(CommandBase._strip_arg(sketch))
+        if programmer:
+            args.extend([flags.PROGRAMMER, CommandBase._strip_arg(programmer)])
         return self._exec(args)
