@@ -24,3 +24,5 @@ DEPS = 'deps'
 CACHE = 'cache'
 CLEAN = 'clean'
 DEBUG = 'debug'
+BURN_BOOTLOADER = 'burn-bootloader'
+COMPLETION = 'completion'
