@@ -27,3 +27,8 @@ LIBRARIES = '--libraries'
 OPTIMIZE_FOR_DEBUG = '--optimize-for-debug'
 DRY_RUN = '--dry-run'
 INTERPRETER = '--interpreter'
+FULL = '--full'
+PROGRAMMER = '--programmer'
+OUTPUT_DIR = '--output-dir'
+NO_DESCRIPTION = '--no-description'
+INPUT_DIR = '--input-dir'
